@@ -6,6 +6,7 @@ _delayed_commutes_to = {
     "abssecond": "absfirst",
     "floordiv": "rfloordiv",
     "rfloordiv": "floordiv",
+    "rpow": "pow",
 }
 from grblas import operator  # noqa isort:skip
 from . import numpy  # noqa isort:skip
@@ -13,6 +14,10 @@ from . import numpy  # noqa isort:skip
 del operator
 
 
+def __dir__():
+    return globals().keys() | _delayed.keys()
+
+
 def __getattr__(key):
     if key in _delayed:
         func, kwargs = _delayed.pop(key)
@@ -23,7 +28,7 @@ def __getattr__(key):
             if other_key in globals():
                 other = globals()[other_key]
             else:
-                other = __getattr__(other_key)
-            rv.commutes_to = other
+                other = other_key
+            rv._commutes_to = other
         return rv
     raise AttributeError(f"module {__name__!r} has no attribute {key!r}")
