@@ -1,5 +1,4 @@
 import itertools
-import warnings
 
 import numpy as np
 
@@ -754,20 +753,6 @@ class Matrix(BaseType):
             at=self._is_transposed,
         )
 
-    def reduce_rows(self, op=monoid.plus):
-        """
-        GrB_Matrix_reduce
-        Reduce all values in each row, converting the matrix to a vector
-        Default op is monoid.lor for boolean and monoid.plus otherwise
-
-        **This function is deprecated.  Please use ``Matrix.reduce_rowwise`` instead.
-        """
-        warnings.warn(
-            "`Matrix.reduce_rows` is deprecated; please use `Matrix.reduce_rowwise` instead",
-            DeprecationWarning,
-        )
-        return self.reduce_rowwise(op)
-
     def reduce_columnwise(self, op=monoid.plus):
         """
         GrB_Matrix_reduce
@@ -790,20 +775,6 @@ class Matrix(BaseType):
             at=not self._is_transposed,
         )
 
-    def reduce_columns(self, op=monoid.plus):
-        """
-        GrB_Matrix_reduce
-        Reduce all values in each column, converting the matrix to a vector
-        Default op is monoid.lor for boolean and monoid.plus otherwise
-
-        **This function is deprecated.  Please use ``Matrix.reduce_columnwise`` instead.
-        """
-        warnings.warn(
-            "`Matrix.reduce_columns` is deprecated; please use `Matrix.reduce_columnwise` instead",
-            DeprecationWarning,
-        )
-        return self.reduce_columnwise(op)
-
     def reduce_scalar(self, op=monoid.plus, *, allow_empty=True):
         """
         GrB_Matrix_reduce
@@ -1373,9 +1344,7 @@ class MatrixExpression(BaseExpression):
     name = wrapdoc(Matrix.name)(property(_automethods.name))
     name = name.setter(_automethods._set_name)
     nvals = wrapdoc(Matrix.nvals)(property(_automethods.nvals))
-    reduce_columns = wrapdoc(Matrix.reduce_columns)(property(_automethods.reduce_columns))
     reduce_columnwise = wrapdoc(Matrix.reduce_columnwise)(property(_automethods.reduce_columnwise))
-    reduce_rows = wrapdoc(Matrix.reduce_rows)(property(_automethods.reduce_rows))
     reduce_rowwise = wrapdoc(Matrix.reduce_rowwise)(property(_automethods.reduce_rowwise))
     reduce_scalar = wrapdoc(Matrix.reduce_scalar)(property(_automethods.reduce_scalar))
     ss = wrapdoc(Matrix.ss)(property(_automethods.ss))
@@ -1453,9 +1422,7 @@ class MatrixIndexExpr(AmbiguousAssignOrExtract):
     name = wrapdoc(Matrix.name)(property(_automethods.name))
     name = name.setter(_automethods._set_name)
     nvals = wrapdoc(Matrix.nvals)(property(_automethods.nvals))
-    reduce_columns = wrapdoc(Matrix.reduce_columns)(property(_automethods.reduce_columns))
     reduce_columnwise = wrapdoc(Matrix.reduce_columnwise)(property(_automethods.reduce_columnwise))
-    reduce_rows = wrapdoc(Matrix.reduce_rows)(property(_automethods.reduce_rows))
     reduce_rowwise = wrapdoc(Matrix.reduce_rowwise)(property(_automethods.reduce_rowwise))
     reduce_scalar = wrapdoc(Matrix.reduce_scalar)(property(_automethods.reduce_scalar))
     ss = wrapdoc(Matrix.ss)(property(_automethods.ss))
@@ -1529,6 +1496,10 @@ class TransposedMatrix:
         rows, cols, vals = self._matrix.to_values(dtype)
         return cols, rows, vals
 
+    @wrapdoc(Matrix.diag)
+    def diag(self, k=0, dtype=None, *, name=None):
+        return self._matrix.diag(-k, dtype, name=name)
+
     @property
     def _carg(self):
         return self._matrix.gb_obj[0]
@@ -1558,8 +1529,6 @@ class TransposedMatrix:
     apply = Matrix.apply
     reduce_rowwise = Matrix.reduce_rowwise
     reduce_columnwise = Matrix.reduce_columnwise
-    reduce_rows = Matrix.reduce_rows
-    reduce_columns = Matrix.reduce_columns
     reduce_scalar = Matrix.reduce_scalar
 
     # Operator sugar
@@ -1584,7 +1553,6 @@ class TransposedMatrix:
     __ixor__ = _automethods.__ixor__
 
     # Misc.
-    diag = Matrix.diag
     isequal = Matrix.isequal
     isclose = Matrix.isclose
     wait = Matrix.wait
