@@ -112,7 +112,7 @@ __all__ = list(_unary_names)
 
 
 def __dir__():
-    return __all__ + list(_delayed)
+    return globals().keys() | _delayed.keys() | _unary_names
 
 
 def __getattr__(name):
